// ------------------------------------------------------------------------ //
// PLAY.C                                                                   //
// ------                                                                   //
// Sample program that demonstrates how to use the 'SoundBlaster Touch Down //
// Library' to play WAV/VOC Files.                                          //
// ------------------------------------------------------------------------ //
//             Programmed by Mario Hewardt (mario@cs.montana.edu)           //
//                          Montana State University                        //
//                                Version 1.0                               //
//                                  06-08-96                                //
// ------------------------------------------------------------------------ //

#include "..\..\sb_tdsrc\sb_tdini.h"  // SB Init. File
#include "..\..\sb_tdsrc\sb_tdwav.h"  // SB Wave File


// Globals....(what can i say. im lazy)!!
struct      SB_Data sbdata;             // SB data
struct      SB_Wave_Data wavedata;      // Wave file data
struct      SB_MIXER_Data mix;          // SB Mixer Data



// ------------------------------------------------------------------------ //
// void init ( )                                                            //
// -------------                                                            //
// Init. the SB. If the autodetection doesnt get the correct values, then   //
// the user can enter command line options to set the SB values             //
// ------------------------------------------------------------------------ //
void init ( )
{
    printf ("Please wait. Autodetecting.........." );
    if ( (SB_Initialize ( &sbdata )) != -1 )
    {
        printf ("\n%s detected at base i/o port %x", sbdata.SB_Model, sbdata.SB_BaseIO );
        SB_Mixer_Initialize ( &mix, sbdata.SB_BaseIO, sbdata.SB_DSP_Major_Version );
    }
    // if no SB detected, the user can specify the SB on the command line
    else
        {printf ("\nNo SoundBlaster detected on your system." ); exit(1);}

}




// ------------------------------------------------------------------------ //
// void wave_banner ( )                                                     //
// --------------------                                                     //
// Prints the intro. banner for the player                                  //
// ------------------------------------------------------------------------ //
void wave_banner ( )
{
    printf ("\n\n==============================================================================");
    printf ("\nWAV/VOC PLAYER  v1.0    ---   By Mario Hewardt  ---   Montana State University" );
    printf ("\n==============================================================================");
    printf ("\n" );
}



// main entry point.
int main ( int argc, char *argv[]  )
{
    wave_banner (); // show dorky intro....
    if ( argc <= 1 )
        {printf ( "Syntax: play <filename.wav>\n\n" );exit(1);}
    // Load the wav file
    if ( ( SB_Wave_LoadInfo ( argv[1], &wavedata ) ) == -1 )
        {printf ( "%s is not a valid wave file.\n\n", argv[1] ); exit(1); }

    init();     // init. SB and other stuff
    SB_Wave_Play ( &wavedata, &sbdata, mix );
    printf ("\nPlaying: %s\n", argv[1] );
    printf ("");
    printf ("Press any key to stop.\n" );
    while ( (SB_Wave_Status()) != SB_TDRET_WAVDONE && !(kbhit()) )
            SB_Wave_Update();

    SB_Wave_Stop ( &wavedata );     // Stop playing and end
    printf ( "Done." );         // stupid msg.
    return 1;
}






