// ------------------------------------------------------------------------- //
// SB_TD345.C     ( CT1345 Mixer Chip )                                      //
// ------------------------------------------------------------------------- //
// Mario Hewardt  (mario@cs.montana.edu)                                     //
// Montana State University                                                  //
// Please read the AGREE.DOC before using.                                   //
// See SB_TD345.DOC for additional information                               //
// ------------------------------------------------------------------------- //


// All functions work with the SBPRO
// ---------------------------------

// ------------------------------------------------------------------------- //
// int SB_CT1345_Present ( struct SB_MIXER_Data )                            //
// ------------------------------------------------------------------------- //
int SB_CT1345_Present ( struct SB_MIXER_Data sbmix )
{
    if ( sbmix.SB_MIXER_Version != 2 )
        return SB_TDRET_MIXERR;
    return SB_TDRET_OK;
}


// ------------------------------------------------------------------------- //
// int SB_CT1345_Get_Source ( struct SB_MIXER_Data )                         //
// ------------------------------------------------------------------------- //
int SB_CT1345_Get_Source ( struct SB_MIXER_Data sbmix )
{
    unsigned status;
    // Is the CT1345 Mixer present?
    if ( sbmix.SB_MIXER_Version != 2 )
        return SB_TDRET_MIXERR;
    SB_MIXER_Set_Adress          ( sbmix,0x0C );  // Set index for input source
    status = SB_MIXER_Read       ( sbmix    );    // read the input source
    return ( (status>>1)&3);                      // mask the correct bits out.
}



// ------------------------------------------------------------------------- //
// int SB_CT1345_Get_StereoSwitch ( struct SB_MIXER_Data )                   //
// ------------------------------------------------------------------------- //
int SB_CT1345_Get_StereoSwitch ( struct SB_MIXER_Data sbmix )
{
    unsigned status;
    // Is the CT1345 Mixer present?
    if ( sbmix.SB_MIXER_Version != 2 )
        return SB_TDRET_MIXERR;
    SB_MIXER_Set_Adress          ( sbmix,0x0E );  // Set index for stereo switch
    status = SB_MIXER_Read       ( sbmix    );    // read the stereo switch
    return ( (status>>1)&1);                      // mask the correct bits out.
}



// ------------------------------------------------------------------------- //
// int SB_CT1345_Get_InputFilter ( struct SB_MIXER_Data )                   //
// ------------------------------------------------------------------------- //
int SB_CT1345_Get_InputFilter ( struct SB_MIXER_Data sbmix )
{
    unsigned status;
    // Is the CT1345 Mixer present?
    if ( sbmix.SB_MIXER_Version != 2 )
        return SB_TDRET_MIXERR;
    SB_MIXER_Set_Adress          ( sbmix,0x0C );  // Set index for input filter
    status = SB_MIXER_Read       ( sbmix    );    // read the input filter
    return ( (status>>5)&1);                      // mask the correct bits out.
}



// ------------------------------------------------------------------------- //
// int SB_CT1345_Get_OutputFilter ( struct SB_MIXER_Data )                   //
// ------------------------------------------------------------------------- //
int SB_CT1345_Get_OutputFilter ( struct SB_MIXER_Data sbmix )
{
    unsigned status;
    // Is the CT1345 Mixer present?
    if ( sbmix.SB_MIXER_Version != 2 )
        return SB_TDRET_MIXERR;
    SB_MIXER_Set_Adress          ( sbmix,0x0E );  // Set index for output filter
    status = SB_MIXER_Read       ( sbmix    );    // read the output filter
    return ( (status>>5)&1);                      // mask the correct bits out.
}



// ------------------------------------------------------------------------- //
// int SB_CT1345_Get_LowPassFilter ( struct SB_MIXER_Data )                  //
// ------------------------------------------------------------------------- //
int SB_CT1345_Get_LowPassFilter ( struct SB_MIXER_Data sbmix )
{
    unsigned status;
    // Is the CT1345 Mixer present?
    if ( sbmix.SB_MIXER_Version != 2 )
        return SB_TDRET_MIXERR;
    SB_MIXER_Set_Adress          ( sbmix,0x0C );  // Set index for input filter
    status = SB_MIXER_Read       ( sbmix    );    // read the input filter
    return ( (status>>3)&1);                      // mask the correct bits out.
}



// ------------------------------------------------------------------------- //
// int SB_CT1345_Get_MasterVolL ( struct SB_MIXER_Data )                     //
// ------------------------------------------------------------------------- //
int SB_CT1345_Get_MasterVolL ( struct SB_MIXER_Data sbmix )
{
    unsigned status;
    // Is the CT1345 Mixer present?
    if ( sbmix.SB_MIXER_Version != 2 )
        return SB_TDRET_MIXERR;
    SB_MIXER_Set_Adress          ( sbmix,0x22 );  // Set index for master volume Left
    status = SB_MIXER_Read       ( sbmix    );    // read the mastervolume Left
    return ( (status>>5)&7);                      // mask the correct bits out.
}



// ------------------------------------------------------------------------- //
// int SB_CT1345_Get_MasterVolR ( struct SB_MIXER_Data )                     //
// ------------------------------------------------------------------------- //
int SB_CT1345_Get_MasterVolR ( struct SB_MIXER_Data sbmix )
{
    unsigned status;
    // Is the CT1345 Mixer present?
    if ( sbmix.SB_MIXER_Version != 2 )
        return SB_TDRET_MIXERR;
    SB_MIXER_Set_Adress          ( sbmix,0x22 );  // Set index for master volume R.
    status = SB_MIXER_Read       ( sbmix    );    // read the mastervolume R.
    return ( (status>>1)&7 );                     // mask the correct bits out.
}


// ------------------------------------------------------------------------- //
// int SB_CT1345_Get_MIDIVolL ( struct SB_MIXER_Data )                       //
// ------------------------------------------------------------------------- //
int SB_CT1345_Get_MIDIVolL ( struct SB_MIXER_Data sbmix )
{
    unsigned status;
    // Is the CT1345 Mixer present?
    if ( sbmix.SB_MIXER_Version != 2 )
        return SB_TDRET_MIXERR;
    SB_MIXER_Set_Adress          ( sbmix,0x26 );  // Set index for MIDI volume Left
    status = SB_MIXER_Read       ( sbmix    );    // read the MIDI volume Left
    return ( (status>>5)&7);                      // mask the correct bits out.
}


// ------------------------------------------------------------------------- //
// int SB_CT1345_Get_MIDIVolR ( struct SB_MIXER_Data )                       //
// ------------------------------------------------------------------------- //
int SB_CT1345_Get_MIDIVolR ( struct SB_MIXER_Data sbmix )
{
    unsigned status;
    // Is the CT1345 Mixer present?
    if ( sbmix.SB_MIXER_Version != 2 )
        return SB_TDRET_MIXERR;
    SB_MIXER_Set_Adress          ( sbmix,0x26 );  // Set index for MIDI volume R.
    status = SB_MIXER_Read       ( sbmix    );    // read the MIDI volume R.
    return ( (status>>1)&7);                      // mask the correct bits out.
}



// ------------------------------------------------------------------------- //
// int SB_CT1345_Get_CDVolL ( struct SB_MIXER_Data )                         //
// ------------------------------------------------------------------------- //
int SB_CT1345_Get_CDVolL ( struct SB_MIXER_Data sbmix )
{
    unsigned status;
    // Is the CT1345 Mixer present?
    if ( sbmix.SB_MIXER_Version != 2 )
        return SB_TDRET_MIXERR;
    SB_MIXER_Set_Adress          ( sbmix,0x28 );  // Set index for CD volume Left
    status = SB_MIXER_Read       ( sbmix    );    // read the CD volume Left
    return ( (status>>5)&7);                      // mask the correct bits out.
}


// ------------------------------------------------------------------------- //
// int SB_CT1345_Get_CDVolR ( struct SB_MIXER_Data )                         //
// ------------------------------------------------------------------------- //
int SB_CT1345_Get_CDVolR ( struct SB_MIXER_Data sbmix )
{
    unsigned status;
    // Is the CT1345 Mixer present?
    if ( sbmix.SB_MIXER_Version != 2 )
        return SB_TDRET_MIXERR;
    SB_MIXER_Set_Adress          ( sbmix,0x28 );  // Set index for CD volume R.
    status = SB_MIXER_Read       ( sbmix    );    // read the CD volume R.
    return ( (status>>1)&7);                      // mask the correct bits out.
}


// ------------------------------------------------------------------------- //
// int SB_CT1345_Get_LineVolL ( struct SB_MIXER_Data )                         //
// ------------------------------------------------------------------------- //
int SB_CT1345_Get_LineVolL ( struct SB_MIXER_Data sbmix )
{
    unsigned status;
    // Is the CT1345 Mixer present?
    if ( sbmix.SB_MIXER_Version != 2 )
        return SB_TDRET_MIXERR;
    SB_MIXER_Set_Adress          ( sbmix,0x2E );  // Set index for Line volume Left
    status = SB_MIXER_Read       ( sbmix    );    // read the Line volume Left
    return ( (status>>5)&7);                      // mask the correct bits out.
}


// ------------------------------------------------------------------------- //
// int SB_CT1345_Get_LineVolR ( struct SB_MIXER_Data )                         //
// ------------------------------------------------------------------------- //
int SB_CT1345_Get_LineVolR ( struct SB_MIXER_Data sbmix )
{
    unsigned status;
    // Is the CT1345 Mixer present?
    if ( sbmix.SB_MIXER_Version != 2 )
        return SB_TDRET_MIXERR;
    SB_MIXER_Set_Adress          ( sbmix,0x2E );  // Set index for Line volume R.
    status = SB_MIXER_Read       ( sbmix    );    // read the Line volume R.
    return ( (status>>1)&7);                      // mask the correct bits out.
}



// ------------------------------------------------------------------------- //
// int SB_CT1345_Get_VoiceVolL ( struct SB_MIXER_Data )                      //
// ------------------------------------------------------------------------- //
int SB_CT1345_Get_VoiceVolL ( struct SB_MIXER_Data sbmix )
{
    unsigned status;
    // Is the CT1345 Mixer present?
    if ( sbmix.SB_MIXER_Version != 2 )
        return SB_TDRET_MIXERR;
    SB_MIXER_Set_Adress          ( sbmix,0x04 );  // Set index for voice volume Left
    status = SB_MIXER_Read       ( sbmix    );    // read the voice volume Left
    return ( (status>>5)&7);                      // mask the correct bits out.
}



// ------------------------------------------------------------------------- //
// int SB_CT1345_Get_VoiceVolR ( struct SB_MIXER_Data )                      //
// ------------------------------------------------------------------------- //
int SB_CT1345_Get_VoiceVolR ( struct SB_MIXER_Data sbmix )
{
    unsigned status;
    // Is the CT1345 Mixer present?
    if ( sbmix.SB_MIXER_Version != 2 )
        return SB_TDRET_MIXERR;
    SB_MIXER_Set_Adress          ( sbmix,0x04 );  // Set index for voice volume R.
    status = SB_MIXER_Read       ( sbmix    );    // read the voice volume R.
    return ( (status>>1)&7);                      // mask the correct bits out.
}



// ------------------------------------------------------------------------- //
// int SB_CT1345_Get_MicVol ( struct SB_MIXER_Data )                         //
// ------------------------------------------------------------------------- //
int SB_CT1345_Get_MicVol ( struct SB_MIXER_Data sbmix )
{
    unsigned status;
    // Is the CT1345 Mixer present?
    if ( sbmix.SB_MIXER_Version != 2 )
        return SB_TDRET_MIXERR;
    SB_MIXER_Set_Adress          ( sbmix,0x0A );  // Set index for mic volume
    status = SB_MIXER_Read       ( sbmix      );  // read the mic volume
    return ( (status>>1)&3);                      // mask the correct bits out.
}



// ------------------------------------------------------------------------- //
// int SB_CT1345_Set_MasterVolL ( struct SB_MIXER_Data, char vol )           //
// ------------------------------------------------------------------------- //
int SB_CT1345_Set_MasterVolL ( struct SB_MIXER_Data sbmix, char vol )
{
    unsigned status;
    // Is the CT1345 Mixer present?
    if ( sbmix.SB_MIXER_Version != 2 )
        return SB_TDRET_MIXERR;
    // Is the vol. in range? (0-7)
    else if ( vol>7 )
        return SB_TDRET_MIXERR;

    // first get the org. values.
    SB_MIXER_Set_Adress    ( sbmix,0x22 );  // Set index for master volume
    status = SB_MIXER_Read ( sbmix    );    // read the mastervolume
    // now set the vol.
    SB_MIXER_Set_Adress    ( sbmix,0x22 );  // Set index for master volume
    SB_MIXER_Write         ( sbmix, (status|vol<<5) );    // mask the correct bits out.
    return status;
}



// ------------------------------------------------------------------------- //
// int SB_CT1345_Set_MasterVolR ( struct SB_MIXER_Data, char vol )           //
// ------------------------------------------------------------------------- //
int SB_CT1345_Set_MasterVolR ( struct SB_MIXER_Data sbmix, char vol )
{
    unsigned status;
    // Is the CT1345 Mixer present?
    if ( sbmix.SB_MIXER_Version != 2 )
        return SB_TDRET_MIXERR;
    // Is the vol. in range? (0-7)
    else if ( vol>7 )
        return SB_TDRET_MIXERR;

    // first get the org. values.
    SB_MIXER_Set_Adress    ( sbmix,0x22 );  // Set index for master volume
    status = SB_MIXER_Read ( sbmix    );    // read the mastervolume
    // now set the vol.
    SB_MIXER_Set_Adress    ( sbmix,0x22 );  // Set index for master volume
    SB_MIXER_Write         ( sbmix, (status|vol<<1) );    // mask the correct bits out.
    return status;
}



// ------------------------------------------------------------------------- //
// int SB_CT1345_Set_MIDIVolL ( struct SB_MIXER_Data, char vol )             //
// ------------------------------------------------------------------------- //
int SB_CT1345_Set_MIDIVolL ( struct SB_MIXER_Data sbmix, char vol )
{
    unsigned status;
    // Is the CT1345 Mixer present?
    if ( sbmix.SB_MIXER_Version != 2 )
        return SB_TDRET_MIXERR;
    // Is the vol. in range? (0-7)
    else if ( vol>7 )
        return SB_TDRET_MIXERR;

    // first get the org. values.
    SB_MIXER_Set_Adress    ( sbmix,0x26 );  // Set index for MIDI volume L.
    status = SB_MIXER_Read ( sbmix    );    // read the MIDI vol. L
    // now set the vol.
    SB_MIXER_Set_Adress    ( sbmix,0x26 );  // Set index for MIDI volume L
    SB_MIXER_Write         ( sbmix, (status|vol<<5) );    // mask the correct bits out.
    return status;
}


// ------------------------------------------------------------------------- //
// int SB_CT1345_Set_MIDIVolR ( struct SB_MIXER_Data, char vol )             //
// ------------------------------------------------------------------------- //
int SB_CT1345_Set_MIDIVolR ( struct SB_MIXER_Data sbmix, char vol )
{
    unsigned status;
    // Is the CT1345 Mixer present?
    if ( sbmix.SB_MIXER_Version != 2 )
        return SB_TDRET_MIXERR;
    // Is the vol. in range? (0-7)
    else if ( vol>7 )
        return SB_TDRET_MIXERR;

    // first get the org. values.
    SB_MIXER_Set_Adress    ( sbmix,0x26 );  // Set index for MIDI volume R.
    status = SB_MIXER_Read ( sbmix    );    // read the MIDI volume R.
    // now set the vol.
    SB_MIXER_Set_Adress    ( sbmix,0x26 );  // Set index for MIDI volume R.
    SB_MIXER_Write         ( sbmix, (status|vol<<1) );    // mask the correct bits out.
    return status;
}


// ------------------------------------------------------------------------- //
// int SB_CT1345_Set_CDVolL ( struct SB_MIXER_Data, char vol )               //
// ------------------------------------------------------------------------- //
int SB_CT1345_Set_CDVolL ( struct SB_MIXER_Data sbmix, char vol )
{
    unsigned status;
    // Is the CT1345 Mixer present?
    if ( sbmix.SB_MIXER_Version != 2 )
        return SB_TDRET_MIXERR;
    // Is the vol. in range? (0-7)
    else if ( vol>7 )
        return SB_TDRET_MIXERR;

    // first get the org. values.
    SB_MIXER_Set_Adress    ( sbmix,0x28 );  // Set index for CD volume L.
    status = SB_MIXER_Read ( sbmix    );    // read the CD volume L.
    // now set the vol.
    SB_MIXER_Set_Adress    ( sbmix,0x28 );  // Set index for CD volume L.
    SB_MIXER_Write         ( sbmix, (status|vol<<5) );    // mask the correct bits out.
    return status;
}



// ------------------------------------------------------------------------- //
// int SB_CT1345_Set_CDVolR ( struct SB_MIXER_Data, char vol )               //
// ------------------------------------------------------------------------- //
int SB_CT1345_Set_CDVolR ( struct SB_MIXER_Data sbmix, char vol )
{
    unsigned status;
    // Is the CT1345 Mixer present?
    if ( sbmix.SB_MIXER_Version != 2 )
        return SB_TDRET_MIXERR;
    // Is the vol. in range? (0-7)
    else if ( vol>7 )
        return SB_TDRET_MIXERR;

    // first get the org. values.
    SB_MIXER_Set_Adress    ( sbmix,0x28 );  // Set index for CD volume R.
    status = SB_MIXER_Read ( sbmix    );    // read the CD volume R.
    // now set the vol.
    SB_MIXER_Set_Adress    ( sbmix,0x28 );  // Set index for CD volume R.
    SB_MIXER_Write         ( sbmix, (status|vol<<1) );    // mask the correct bits out.
    return status;
}



// ------------------------------------------------------------------------- //
// int SB_CT1345_Set_LineVolL ( struct SB_MIXER_Data, char vol )             //
// ------------------------------------------------------------------------- //
int SB_CT1345_Set_LineVolL ( struct SB_MIXER_Data sbmix, char vol )
{
    unsigned status;
    // Is the CT1345 Mixer present?
    if ( sbmix.SB_MIXER_Version != 2 )
        return SB_TDRET_MIXERR;
    // Is the vol. in range? (0-7)
    else if ( vol>7 )
        return SB_TDRET_MIXERR;

    // first get the org. values.
    SB_MIXER_Set_Adress    ( sbmix,0x2E );  // Set index for Line volume L.
    status = SB_MIXER_Read ( sbmix    );    // read the Line volume L.
    // now set the vol.
    SB_MIXER_Set_Adress    ( sbmix,0x2E );  // Set index for Line  volume L.
    SB_MIXER_Write         ( sbmix, (status|vol<<5) );    // mask the correct bits out.
    return status;
}


// ------------------------------------------------------------------------- //
// int SB_CT1345_Set_LineVolR ( struct SB_MIXER_Data, char vol )             //
// ------------------------------------------------------------------------- //
int SB_CT1345_Set_LineVolR ( struct SB_MIXER_Data sbmix, char vol )
{
    unsigned status;
    // Is the CT1345 Mixer present?
    if ( sbmix.SB_MIXER_Version != 2 )
        return SB_TDRET_MIXERR;
    // Is the vol. in range? (0-7)
    else if ( vol>7 )
        return SB_TDRET_MIXERR;

    // first get the org. values.
    SB_MIXER_Set_Adress    ( sbmix,0x2E );  // Set index for Line  volume R.
    status = SB_MIXER_Read ( sbmix    );    // read the Line volume R.
    // now set the vol.
    SB_MIXER_Set_Adress    ( sbmix,0x2E );  // Set index for Line volume R.
    SB_MIXER_Write         ( sbmix, (status|vol<<1) );    // mask the correct bits out.
    return status;
}




// ------------------------------------------------------------------------- //
// int SB_CT1345_Set_VoiceVolL ( struct SB_MIXER_Data, char vol )            //
// ------------------------------------------------------------------------- //
int SB_CT1345_Set_VoiceVolL ( struct SB_MIXER_Data sbmix, char vol )
{
    unsigned status;
    // Is the CT1345 Mixer present?
    if ( sbmix.SB_MIXER_Version != 2 )
        return SB_TDRET_MIXERR;
    // Is the vol. in range? (0-7)
    else if ( vol>7 )
        return SB_TDRET_MIXERR;

    // first get the org. values.
    SB_MIXER_Set_Adress    ( sbmix,0x04 );  // Set index for Voice volume L.
    status = SB_MIXER_Read ( sbmix    );    // read the Voice volume L.
    // now set the vol.
    SB_MIXER_Set_Adress    ( sbmix,0x04 );  // Set index for Voice  volume L.
    SB_MIXER_Write         ( sbmix, (status|vol<<5) );    // mask the correct bits out.
    return status;
}



// ------------------------------------------------------------------------- //
// int SB_CT1345_Set_VoiceVolR ( struct SB_MIXER_Data, char vol )            //
// ------------------------------------------------------------------------- //
int SB_CT1345_Set_VoiceVolR ( struct SB_MIXER_Data sbmix, char vol )
{
    unsigned status;
    // Is the CT1345 Mixer present?
    if ( sbmix.SB_MIXER_Version != 2 )
        return SB_TDRET_MIXERR;
    // Is the vol. in range? (0-7)
    else if ( vol>7 )
        return SB_TDRET_MIXERR;

    // first get the org. values.
    SB_MIXER_Set_Adress    ( sbmix,0x04 );  // Set index for Voice volume R.
    status = SB_MIXER_Read ( sbmix    );    // read the Voice volume R.
    // now set the vol.
    SB_MIXER_Set_Adress    ( sbmix,0x04 );  // Set index for Voice  volume R.
    SB_MIXER_Write         ( sbmix, (status|vol<<1) );    // mask the correct bits out.
    return status;
}



// ------------------------------------------------------------------------- //
// int SB_CT1345_Set_MicVol ( struct SB_MIXER_Data, char vol )               //
// ------------------------------------------------------------------------- //
int SB_CT1345_Set_MicVol ( struct SB_MIXER_Data sbmix, char vol )
{
    unsigned status;
    // Is the CT1345 Mixer present?
    if ( sbmix.SB_MIXER_Version != 2 )
        return SB_TDRET_MIXERR;
    // Is the vol. in range? (0-7)
    else if ( vol>3 )
        return SB_TDRET_MIXERR;

    // first get the org. values.
    SB_MIXER_Set_Adress    ( sbmix,0x0A );  // Set index for Mic volume
    status = SB_MIXER_Read ( sbmix    );    // read the Mic volume
    // now set the vol.
    SB_MIXER_Set_Adress    ( sbmix,0x0A );  // Set index for Mic  volume
    SB_MIXER_Write         ( sbmix, (status|vol<<1) );    // mask the correct bits out.
    return status;
}



// ------------------------------------------------------------------------- //
// int SB_CT1345_Set_Source ( struct SB_MIXER_Data, char vol )               //
// ------------------------------------------------------------------------- //
int SB_CT1345_Set_Source ( struct SB_MIXER_Data sbmix, char src )
{
    unsigned status;
    // Is the CT1345 Mixer present?
    if ( sbmix.SB_MIXER_Version != 2 )
        return SB_TDRET_MIXERR;
    // Is the src. in range? (0-3)
    else if ( src>3 )
        return SB_TDRET_MIXERR;

    // first get the org. values.
    SB_MIXER_Set_Adress    ( sbmix,0x0C );  // Set index for Input source.
    status = SB_MIXER_Read ( sbmix    );    // read the input source.
    // now set the src
    SB_MIXER_Set_Adress    ( sbmix,0x0C );  // Set index for Input source.
    SB_MIXER_Write         ( sbmix, (status|src<<1) );    // mask the correct bits out.
    return status;
}



// ------------------------------------------------------------------------- //
// int SB_CT1345_Set_InputFilter ( struct SB_MIXER_Data, char vol )          //
// ------------------------------------------------------------------------- //
int SB_CT1345_Set_InputFilter ( struct SB_MIXER_Data sbmix, char src )
{
    unsigned status;
    // Is the CT1345 Mixer present?
    if ( sbmix.SB_MIXER_Version != 2 )
        return SB_TDRET_MIXERR;
    // Is the src. in range? (0-1)
    else if ( src>1 )
        return SB_TDRET_MIXERR;

    // first get the org. values.
    SB_MIXER_Set_Adress    ( sbmix,0x0C );  // Set index for Input filter.
    status = SB_MIXER_Read ( sbmix    );    // read the input filter.
    // now set the src
    SB_MIXER_Set_Adress    ( sbmix,0x0C );  // Set index for Input filter.
    SB_MIXER_Write         ( sbmix, (status|src<<5) );    // mask the correct bits out.
    return status;
}




// ------------------------------------------------------------------------- //
// int SB_CT1345_Set_LowPassFilter ( struct SB_MIXER_Data, char vol )        //
// ------------------------------------------------------------------------- //
int SB_CT1345_Set_LowPassFilter ( struct SB_MIXER_Data sbmix, char src )
{
    unsigned status;
    // Is the CT1345 Mixer present?
    if ( sbmix.SB_MIXER_Version != 2 )
        return SB_TDRET_MIXERR;
    // Is the src. in range? (0-1)
    else if ( src>1 )
        return SB_TDRET_MIXERR;

    // first get the org. values.
    SB_MIXER_Set_Adress    ( sbmix,0x0C );  // Set index for Input filter.
    status = SB_MIXER_Read ( sbmix    );    // read the input filter.
    // now set the src
    SB_MIXER_Set_Adress    ( sbmix,0x0C );  // Set index for Input source.
    SB_MIXER_Write         ( sbmix, (status|src<<3) );    // mask the correct bits out.
    return status;
}



// ------------------------------------------------------------------------- //
// int SB_CT1345_Set_StereoSwitch ( struct SB_MIXER_Data, char vol )         //
// ------------------------------------------------------------------------- //
int SB_CT1345_Set_StereoSwitch ( struct SB_MIXER_Data sbmix, char src )
{
    unsigned status;
    // Is the CT1345 Mixer present?
    if ( sbmix.SB_MIXER_Version != 2 )
        return SB_TDRET_MIXERR;
    // Is the src. in range? (0-1)
    else if ( src>1 )
        return SB_TDRET_MIXERR;

    // first get the org. values.
    SB_MIXER_Set_Adress    ( sbmix,0x0E );  // Set index for stereo switch.
    status = SB_MIXER_Read ( sbmix    );    // read the stereoswitch.
    // now set the src
    SB_MIXER_Set_Adress    ( sbmix,0x0E );  // Set index for stereo switch.
    SB_MIXER_Write         ( sbmix, (status|src<<1) );    // mask the correct bits out.
    return status;
}



// ------------------------------------------------------------------------- //
// int SB_CT1345_Set_OutputFilter ( struct SB_MIXER_Data, char vol )         //
// ------------------------------------------------------------------------- //
int SB_CT1345_Set_OutputFilter ( struct SB_MIXER_Data sbmix, char src )
{
    unsigned status;
    // Is the CT1345 Mixer present?
    if ( sbmix.SB_MIXER_Version != 2 )
        return SB_TDRET_MIXERR;
    // Is the src. in range? (0-1)
    else if ( src>1 )
        return SB_TDRET_MIXERR;

    // first get the org. values.
    SB_MIXER_Set_Adress    ( sbmix,0x0E );  // Set index for Output filter.
    status = SB_MIXER_Read ( sbmix    );    // read the Output filter.
    // now set the src
    SB_MIXER_Set_Adress    ( sbmix,0x0E );  // Set index for Output filter.
    SB_MIXER_Write         ( sbmix, (status|src<<5) );    // mask the correct bits out.
    return status;
}

