// ------------------------------------------------------------------------- //
// SB_TDDMA.C	  ( Direct Memory Access Engine )							 //
// ------------------------------------------------------------------------- //
// Mario Hewardt  (mario@cs.montana.edu)									 //
// Montana State University 												 //
// Please read the AGREE.DOC before using.									 //
// See SB_TDLIB.DOC or SB_TDNOT.DOC for additional information				 //
// ------------------------------------------------------------------------- //


// ------------------------------------------------------------------------- //
// void SB_DMA_Cenable ( int )												 //
// ------------------------------------------------------------------------- //
void SB_DMA_Cenable ( int channel )
{
	if ( channel<4 )
		outp ( SB_DMA_CMASK8, channel );	   // channels 0,1,3
	else
		outp ( SB_DMA_CMASK16, channel );	   // channels 4,5,6,7
}


// ------------------------------------------------------------------------- //
// void SB_DMA_Cdisable ( int ) 											 //
// ------------------------------------------------------------------------- //
void SB_DMA_Cdisable ( int channel )
{
	if ( channel<4 )
		outp ( SB_DMA_CMASK8, channel+0x04 );		// channels 0,1,3
	else
		outp ( SB_DMA_CMASK16, channel+0x04 );		// channels 4,5,6,7
}


// ------------------------------------------------------------------------- //
// void SB_DMA_Cclear ( int )												 //
// ------------------------------------------------------------------------- //
void SB_DMA_Cclear ( int channel )
{
	if ( channel<4 )
		outp ( SB_DMA_CLEAR8, 0x00 );		// channels 0,1,3
	else
		outp ( SB_DMA_CLEAR16, 0x00 );		// channels 4,5,6,7
}


// ------------------------------------------------------------------------- //
// void SB_DMA_Cmode ( struct SB_DMA_Data * )								 //
// ------------------------------------------------------------------------- //
void SB_DMA_Cmode ( struct SB_DMA_Data *dma )
{
	if ( dma->SB_DMA_Channel<4 )
		outp ( SB_DMA_MODE8, dma->SB_DMA_Mode+dma->SB_DMA_Channel );
	else
		outp ( SB_DMA_MODE16, dma->SB_DMA_Mode+dma->SB_DMA_Channel );
}


// ------------------------------------------------------------------------- //
// void SB_DMA_Cpage ( struct SB_DMA_Data * )								 //
// ------------------------------------------------------------------------- //
void SB_DMA_Cpage ( struct SB_DMA_Data *dma )
{
		outp ( SB_DMA_Page[dma->SB_DMA_Channel], dma->SB_DMA_Page );
}


// ------------------------------------------------------------------------- //
// void SB_DMA_Coffset ( struct SB_DMA_Data * ) 							 //
// ------------------------------------------------------------------------- //
void SB_DMA_Coffset ( struct SB_DMA_Data *dma )
{
		USWORD address=(((UDWORD)dma->SB_DMA_Cont)&0xFFFF);
		outp ( SB_DMA_Offset[dma->SB_DMA_Channel], (address&0xFF) );
		outp ( SB_DMA_Offset[dma->SB_DMA_Channel], (address>>8) );
}

// ------------------------------------------------------------------------- //
// void SB_DMA_Clength ( struct SB_DMA_Data * ) 							 //
// ------------------------------------------------------------------------- //
void SB_DMA_Clength ( struct SB_DMA_Data *dma )
{
		dma->SB_DMA_Length--;
		outp ( SB_DMA_Length[dma->SB_DMA_Channel], (dma->SB_DMA_Length&0x0FF) );
		outp ( SB_DMA_Length[dma->SB_DMA_Channel], (dma->SB_DMA_Length)>>8 );
		dma->SB_DMA_Length++;

}



// ------------------------------------------------------------------------- //
// int SB_DMA_Alloc ( struct SB_DMA_Data, int ) 							 //
// ------------------------------------------------------------------------- //
int SB_DMA_Alloc ( struct SB_DMA_Data *dma, int size )
{
	UDWORD addr;
	static union REGS reg;
	reg.x.eax = 0x0100; 			 // DPMI Mem. Allocation
	reg.x.ebx = ((size*2)+15>>4);	 // # of paragraphs to alloc.
	int386 ( 0x31, &reg,&reg ); 	 // do it!!
    if ( reg.x.cflag ) return SB_TDRET_MEMERR;    // error alloc. mem.
	dma->SB_DMA_Selector=reg.x.edx;  // get the base selector
	addr=(reg.x.eax&0xFFFF)<<4; 	 // get the real segment adress
	// to guarantee page continous, allocate twice the size of mem pool.
	// used in mikxmas player........
	if ( (addr>>16) != ((addr+size-1)>>16) )
		addr+=size;

	dma->SB_DMA_Page=addr>>16;		 // Get the page
	dma->SB_DMA_Cont = (void *) addr;// get the 20 bit real adress
	dma->SB_DMA_Length=size;		 // store the size of the data
    return SB_TDRET_OK;
}



// ------------------------------------------------------------------------- //
// int SB_DMA_Free ( struct SB_DMA_Data )									 //
// ------------------------------------------------------------------------- //
int SB_DMA_Free ( struct SB_DMA_Data *dma )
{
	static union REGS reg;
	reg.x.eax = 0x0101; 				// DPMI mem. dealloc.
	reg.x.edx = dma->SB_DMA_Selector;	// get the selector
	int386 ( 0x31, &reg, &reg );		// do it!!
    if ( reg.x.cflag ) return SB_TDRET_MEMERR;       // error dealloc --> exit
    return SB_TDRET_OK;                           // if not....KEWL !!!
}



// ------------------------------------------------------------------------- //
// int SB_DMA_Pause ( struct SB_DMA_Data )									 //
// ------------------------------------------------------------------------- //
void SB_DMA_Pause ( int channel )
{
	if ( channel<4 )
		outp ( SB_DMA_CMASK8, 0x04+channel );		// channels 0,1,3
	else
		outp ( SB_DMA_CMASK16, 0x04+channel );		// channels 4,5,6,7
}


// ------------------------------------------------------------------------- //
// int SB_DMA_UnPause ( struct SB_DMA_Data )								 //
// ------------------------------------------------------------------------- //
int SB_DMA_UnPause ( int channel )
{
	if ( channel<4 )
		outp ( SB_DMA_CMASK8, channel );	   // channels 0,1,3
	else
		outp ( SB_DMA_CMASK16, channel );	   // channels 4,5,6,7
	return 1;
}



// ------------------------------------------------------------------------- //
// int SB_DMA_Transfered ( struct SB_DMA_Data ) 							 //
// ------------------------------------------------------------------------- //
USWORD SB_DMA_Transfered ( int channel )
{
	USWORD temp=0;
	temp= (inp ( SB_DMA_Length[channel] )<<8);				 // MSB
	temp= (inp ( SB_DMA_Length[channel] )<<8)&0xFF00;	  // LSB
	return temp;
}



