// ------------------------------------------------------------------------- //
// SB_TDDMA.H	  ( Direct Memory Access Engine Header File )				 //
// ------------------------------------------------------------------------- //
// Mario Hewardt  (mario@cs.montana.edu)									 //
// Montana State University 												 //
// Please read the AGREE.DOC before using.									 //
// See SB_TDLIB.DOC or SB_TDNOT.DOC for additional information				 //
// ------------------------------------------------------------------------- //


#ifndef _DOS_H_INCLUDED
#include <dos.h>
#endif

#ifndef __SBTDRET
#include "sb_tdret.h"
#endif

#ifndef __SBTDDMA
#define __SBTDDMA


#include "sb_tdcom.h"       // common data types

// Globals (EEEERRRRRRR!!!!!!), makes it look nice though :)
// ---------------------------------------------------------
USCHAR SB_DMA_Page[8]  ={0x87,0x83,0x81,0x82,0x8F,0x8B,0x89,0x8A};
USCHAR SB_DMA_Offset[8]={0x00,0x02,0x04,0x06,0xC0,0xC4,0xC8,0xCC};
USCHAR SB_DMA_Length[8]={0x01,0x03,0x05,0x07,0xC2,0xC6,0xCA,0xCE};

// Misc. DMA registers (8&16bit)
// -----------------------------
#define SB_DMA_CMASK8	0x0A		// 8 Bit DMA Channel Mask reg.
#define SB_DMA_CMASK16	0xD4		// 16 Bit DMA Channel Mask reg.
#define SB_DMA_CLEAR8	0x0C		// 8 Bit DMA Reset adress ptr reg.
#define SB_DMA_CLEAR16	0xD8		// 16 Bit DMA Reset adress ptr reg.
#define SB_DMA_MODE8	0x0B		// 8 Bit DMA Transfer Mode reg.
#define SB_DMA_MODE16	0xD6		// 16 Bit DMA Transfer Mode reg.



// DMA Mem structure.
// ------------------
struct SB_DMA_Data
{
	void  *SB_DMA_Cont; 		  // pointer to continous allocated memory
	USWORD SB_DMA_Selector; 	  // Base selector
	int    SB_DMA_Channel;		  // channel for dma transfer
	int    SB_DMA_Mode; 		  // transfer mode
	USWORD SB_DMA_Length;		  // # of bytes to transfer
	USCHAR SB_DMA_Page; 		  // page
};


// function prototypes
// -------------------
void SB_DMA_Cenable  ( int						 );
void SB_DMA_Cdisable ( int						 );
void SB_DMA_Cclear	 ( int						 );
void SB_DMA_Cmode	 ( struct SB_DMA_Data * 	 );
void SB_DMA_Cpage	 ( struct SB_DMA_Data * 	 );
void SB_DMA_Coffset  ( struct SB_DMA_Data * 	 );
void SB_DMA_Clength  ( struct SB_DMA_Data * 	 );
int  SB_DMA_Alloc	 ( struct SB_DMA_Data *, int );
int  SB_DMA_Free	 ( struct SB_DMA_Data * 	 );



// include the code please.....
// ----------------------------
#include "sb_tddma.c"

#endif		// __SBTDDMA

