// ------------------------------------------------------------------------- //
// SB_TDDSP.C     ( Digital Sound Processor Engine )                         //
// ------------------------------------------------------------------------- //
// Mario Hewardt  (mario@cs.montana.edu)                                     //
// Montana State University                                                  //
// Please read the AGREE.DOC before using.                                   //
// See SB_TDLIB.DOC or SB_TDNOT.DOC for additional information               //
// ------------------------------------------------------------------------- //



// ------------------------------------------------------------------------- //
// void SB_DSP_SpeakOnOff ( int base, int flag )                         (SB)//
// ------------------------------------------------------------------------- //
void SB_DSP_SpeakOnOff ( int base, int flag )
{
    if ( flag==1 )  // turn on
        SB_DSP_Write ( base, SB_DSP_DACON );
    else            // turn off
        SB_DSP_Write ( base, SB_DSP_DACOFF );
}



// ------------------------------------------------------------------------- //
// void SB_DSP_AcknowInt ( int base )                                    (SB)//
// ------------------------------------------------------------------------- //
void SB_DSP_AcknowInt ( int base, int irq )
{
    if ( irq < 8 )
        inp ( base+SB_DSP_ACKINT8 );
    else
        inp ( base+SB_DSP_ACKINT16 );
}


// ------------------------------------------------------------------------- //
// void SB_DSP_RequestInt ( int base )                                  (SB) //
// ------------------------------------------------------------------------- //
void SB_DSP_RequestInt ( int base, int major )
{
    if ( major < 4 )
        SB_DSP_Write ( base, SB_DSP_REQINT8 );
    else
        SB_DSP_Write ( base, SB_DSP_REQINT16 );
}



// ------------------------------------------------------------------------- //
// int SB_DSP_Write ( int sb_base_adress, char func )              (SB)      //
// ------------------------------------------------------------------------- //
void SB_DSP_Write ( int sb_base_adress, USCHAR func )
{
    while ( (inp(sb_base_adress+SB_DSP_CMDWRITE)&0x80) ) ;
    outp ( sb_base_adress+SB_DSP_CMDWRITE, func ); // yeap...write the val.
}


// ------------------------------------------------------------------------- //
// int SB_DSP_Read ( int base )                                    (SB)      //
// ------------------------------------------------------------------------- //
USCHAR SB_DSP_Read ( int sb_base_adress )
{
      while ( !(inp(sb_base_adress+SB_DSP_DATAPRESENT)&0x80) ) ;
      return ( inp ( sb_base_adress+SB_DSP_READ ) ); // yeap...write the val.
}


// ------------------------------------------------------------------------- //
// int SB_DSP_Version ( int base, int *major, int *minor )         (SB)      //
// ------------------------------------------------------------------------- //
void SB_DSP_Version ( int base, int *major, int *minor  )
{
    SB_DSP_Write ( base, SB_DSP_VERSION );
    *major = SB_DSP_Read  ( base );     // Get major version
    *minor = SB_DSP_Read  ( base );     // Get minor version
}


// ------------------------------------------------------------------------- //
// int SB_DSP_Reset ( int base_port  )                             (SB)      //
// ------------------------------------------------------------------------- //
int SB_DSP_Reset ( int base_port )
{
        int index2;
        unsigned status;

        outp ( base_port+SB_DSP_RESET, 1 );  // write 1 to DSP RESET PORT
        inp ( base_port );                  // wait for 3 microsec.
        inp ( base_port );                  // hehehe..nice wait routine :)
        inp ( base_port );
        inp ( base_port );
        outp ( base_port+SB_DSP_RESET, 0 );   // write 0 to DSP RESET PORT

        index2=0;
        while ( index2<100 )
        {
            status = inp ( base_port+SB_DSP_DATAPRESENT ); // Check if data is available DSP_READ_BUFFER_STATUS
            if ( (status&0x80) ) // If bit 7 is set data is available
            {
                status = inp ( base_port+SB_DSP_READ );    // Read data from DSP_READ
                if ( status == 0xAA )      // if read byte is AAh DSP is reset
                    return SB_TDRET_OK;          // YEAHHH, SB detected.....
            }
            index2++;
        }
        return SB_TDRET_NOSB;
}



