// ------------------------------------------------------------------------- //
// SB_TDDSP.H     ( Digital Sound Processor Engine )                         //
// ------------------------------------------------------------------------- //
// Mario Hewardt  (mario@cs.montana.edu)                                     //
// Montana State University                                                  //
// Please read the AGREE.DOC before using.                                   //
// See SB_TDLIB.DOC or SB_TDNOT.DOC for additional information               //
// ------------------------------------------------------------------------- //


#ifndef __SBTDRET
#include "sb_tdret.h"
#endif

// Make sure sb_tddsp.h doesnt get included more than once.
#ifndef __SBTDDSP
#define __SBTDDSP


#include "sb_tdcom.h"       // dont forget the common file

// Function prototypes
// -------------------
unsigned char  SB_DSP_Read          ( int                   );       // (SB)
int            SB_DSP_Write         ( int, unsigned char    );       // (SB)
int            SB_DSP_Version       ( int, int *, int *     );       // (SB)
int            SB_DSP_Reset         ( int                   );       // (SB)
void           SB_DSP_AcknowInt     ( int, int              );       // (SB/SB16)
void           SB_DSP_RequestInt    ( int, int              );       // (SB)
void           SB_DSP_SpeakOnOff    ( int, int              );       // (SB)








// Misc. DSP reg.
// --------------
#define SB_DSP_CMDWRITE         0x0C        // Write data or command
#define SB_DSP_DATAPRESENT      0x0E        // Data Available Status
#define SB_DSP_VERSION          0xE1        // Version #
#define SB_DSP_RESET            0x06        // Reset
#define SB_DSP_READ             0x0A        // Read data
#define SB_DSP_TIMECONST        0x40        // Set time const.
#define SB_DSP_DACON            0xD1        // DAC Speaker on
#define SB_DSP_DACOFF           0xD3        // DAC Speaker off
#define SB_DSP_DMASIZE          0x48        // DMA Block Size
#define SB_DSP_AIEXIT           0xDA        // Auto Init Exit
#define SB_DSP_ACKINT8          0x0E        // Acknowledge Interrupt 8 bit
#define SB_DSP_ACKINT16         0x0F        // Acknowledge Interrupt 16 bit
#define SB_DSP_REQINT8          0xF2        // Request Interrupt 8 bit
#define SB_DSP_REQINT16         0xF3        // Request Interrupt 16 bit


#include "sb_tddsp.c"       // DSP functions

#endif  // __SBTDDSP



