// ------------------------------------------------------------------------- //
// SB_TDINI.C     ( Sound Blaster Initialization file )                      //
// ------------------------------------------------------------------------- //
// Mario Hewardt  (mario@cs.montana.edu)                                     //
// Montana State University                                                  //
// Please read the AGREE.DOC before using.                                   //
// See SB_TDLIB.DOC or SB_TDNOT.DOC for additional information               //
// ------------------------------------------------------------------------- //



// ------------------------------------------------------------------------- //
// int SB_Initialize ( struct SB_Data * )                          (SB)      //
// ------------------------------------------------------------------------- //
int SB_Initialize ( struct SB_Data *sbdata  )
{
    int basedec[7]={210,220,230,240,250,260,280};
    int basehex[7]={0x210, 0x220, 0x230, 0x240, 0x250, 0x260, 0x280};
    int index;
    int  major,minor;
    unsigned status;

    // reset the blaster structure...hmmm..memset would be easier
    sbdata->SB_BaseIO=-1;
    sbdata->SB_IRQ=-1;
    sbdata->SB_DMA8_Channel=-1;
    sbdata->SB_DMA16_Channel=-1;
    sbdata->SB_DSP_Major_Version=-1;
    sbdata->SB_DSP_Minor_Version=-1;
    sbdata->SB_Version=-1;
    strcpy ( sbdata->SB_Model, "\0" );

    if ( SB_Init_Env ( sbdata ) == 1 )
    {
    // SB has been detected. index repr. the index to base adress
    // Now get additional info about SB
    // ----------------------------------------------------------
        if ( sbdata->SB_BaseIO == -1 )
            return SB_TDRET_NOBASEIO;          // gotta have Base io
        if ( sbdata->SB_DMA8_Channel == -1 )
            return SB_TDRET_NODMA8;          // gotta have 8 bit DMA !!!
        else if ( sbdata->SB_IRQ == -1 )
            return SB_TDRET_NOIRQ;          // gotta have IRQ

        for ( index=0; index<7; index++ )
            if ( sbdata->SB_BaseIO == basedec[index] )
                sbdata->SB_BaseIO = basehex[index];

        SB_DSP_Reset ( sbdata->SB_BaseIO );
        SB_DSP_Version ( sbdata->SB_BaseIO, &major, &minor );
        sbdata->SB_DSP_Major_Version = major;
        sbdata->SB_DSP_Minor_Version = minor;
        // Set the model type
        if ( major==1 )
        {
                strcpy ( sbdata->SB_Model, "SoundBlaster 1.0/1.5" );
                sbdata->SB_Version=SB_10_15;
        }
        else if ( major==3 )
        {
            status=inp ( 0x338 );
            if ( status==6 )
            {
                strcpy ( sbdata->SB_Model, "SoundBlaster Pro (Early/OLE2)" );
                sbdata->SB_Version=SB_PRO;
            }
            else
            {
                strcpy ( sbdata->SB_Model, "SoundBlaster Pro (Late/OLE3)" );
                sbdata->SB_Version=SB_PRO2;
            }
        }
        else if ( major==4 )
        {
            if ( sbdata->SB_DMA16_Channel == -1 )
                return SB_TDRET_NODMA16;
            strcpy ( sbdata->SB_Model, "SoundBlaster 16" );
            sbdata->SB_Version=SB_16;
        }
        else
        {
            strcpy ( sbdata->SB_Model, "SoundBlaster model unknown" );
            sbdata->SB_Version=SB_UNKNOWN;
        }
        return SB_TDRET_OK;
    }

    // No SB detected. return -1
    else
    {
        strcpy ( sbdata->SB_Model, "No SoundBlaster detected" );
        sbdata->SB_Version=SB_NONE;
        return SB_TDRET_NOSB;
    }
}



// ------------------------------------------------------------------------- //
// int SB_Init_Env ( struct SB_Data * )                            (SB)      //
// ------------------------------------------------------------------------- //
int SB_Init_Env ( struct SB_Data *sbdata )
{
    char let[4]={'A','I','D','H'};
    char *blastenv; char tmp[10]; int stat;
    char *cpy;

    blastenv = (char *) malloc ( 40 );

    if ( ( blastenv=getenv("BLASTER")) != 0 )
    {
        // Gets info about Base Adress, IRQ, DMA8/16
        // If any of these fields are -1 after init. then not found in env
        // ---------------------------------------------------------------
        cpy=blastenv;
        if ( ( stat=SB_Find_Letter ( 'A', blastenv ) ) == -1 )
            sbdata->SB_BaseIO=-1;
        else
            sbdata->SB_BaseIO=stat;
        if ( ( stat=SB_Find_Letter ( 'I', blastenv ) ) == -1 )
            sbdata->SB_IRQ=-1;
        else
            sbdata->SB_IRQ=stat;
        if ( ( stat=SB_Find_Letter ( 'D', blastenv ) ) == -1 )
            sbdata->SB_DMA8_Channel=-1;
        else
            sbdata->SB_DMA8_Channel=stat;
        if ( ( stat=SB_Find_Letter ( 'H', blastenv ) ) == -1 )
            sbdata->SB_DMA16_Channel=-1;
        else
            sbdata->SB_DMA16_Channel=stat;
        return 1;
    }
    else
        return -1;      // Env. Table not found or incomplete
}


// ------------------------------------------------------------------------- //
// int SB_Find_Letter ( char , char * )                                      //
// ------------------------------------------------------------------------- //
int SB_Find_Letter ( char tmp, char *env )
{
    char cpy[5];
    int i;
    i=0;

    // Extract individual segments of the BLASTER Env.
    while ( *(env+i) != 0 && *(env+i) != tmp )
        i++;
    if ( *(env+i) ==0 )
        return -1;      // not found in env str.
    else
    {
        env+=i+1; i=0;
        while ( *(env+i) != 0 && *(env+i) != ' ' )
            {cpy[i]=*(env+i);i++;}
        cpy[i]=0;
        return (atoi(cpy));
    }
}

