// ------------------------------------------------------------------------- //
// SB_TDIRQ.C     ( Sound Blaster IRQ file )                                 //
// ------------------------------------------------------------------------- //
// Mario Hewardt  (mario@cs.montana.edu)                                     //
// Montana State University                                                  //
// ------------------------------------------------------------------------- //



// ------------------------------------------------------------------------- //
// void SB_IRQ_DisableAll (  )                                               //
// ------------------------------------------------------------------------- //
void SB_IRQ_DisableAll ( )
{
    outp ( 0x21, 0xFF );
    outp ( 0xA1, 0xFF );
}


// ------------------------------------------------------------------------- //
// void SB_IRQ_SetMask (  )                                                  //
// ------------------------------------------------------------------------- //
void SB_IRQ_SetMask ( )
{
    SB_IRQ_Mask1=inp ( 0x21 );
    SB_IRQ_Mask2=inp ( 0xA1 );
}

// ------------------------------------------------------------------------- //
// void SB_IRQ_Enable ( unsigned char irqnum )                               //
// ------------------------------------------------------------------------- //
void SB_IRQ_Enable ( USCHAR irqnum )
{
    USCHAR tmp=1;

    if ( SB_IRQ_Mask1 == -1 )
        SB_IRQ_Mask1 = inp ( 0x21 );
    else if ( SB_IRQ_Mask2 == -1 )
        SB_IRQ_Mask2=inp ( 0xA1 );

    if ( irqnum < 8 )
        outp (0x21, (SB_IRQ_Mask1^(tmp<<irqnum) ) );     // IRQ 0-7
    else
        outp (0xA1, (SB_IRQ_Mask2^(tmp<<(irqnum-8)) ) );    // IRQ 8-15

}



// ------------------------------------------------------------------------- //
// void SB_IRQ_RestoreMask (  )                                              //
// ------------------------------------------------------------------------- //
void SB_IRQ_RestoreMask (  )
{
    if ( SB_IRQ_Mask1!=-1)
        outp (0x21, SB_IRQ_Mask1 );     // IRQ 0-7
    else if ( SB_IRQ_Mask2 != -1 )
        outp (0xA1, SB_IRQ_Mask2 );     // IRQ 8-15
}




// ------------------------------------------------------------------------- //
// void SB_IRQ_End ( int irqnum )                                            //
// ------------------------------------------------------------------------- //
void SB_IRQ_End ( USCHAR irqnum )
{
    outp ( 0x20, 0x20 );
    if ( irqnum > 7 )
        outp ( 0xA0, 0x20 );
}


// ------------------------------------------------------------------------- //
//  SB_FUNCPTR SB_IRQ_SetHandler ( int irqnum, SB_FUNCPTR handler )          //
// ------------------------------------------------------------------------- //
SB_FUNCPTR SB_IRQ_SetHandler ( USCHAR irqnum, SB_FUNCPTR handler )
{
    SB_FUNCPTR oldvect;

    if ( irqnum < 8 )
    {
        oldvect = _dos_getvect ( irqnum+0x8 );
        _dos_setvect ( irqnum+0x8, handler );
    }
    else
    {
        oldvect = _dos_getvect ( irqnum+0x72 );
        _dos_setvect ( 0x72, handler );
    }
    return oldvect;
}


