// ------------------------------------------------------------------------- //
// SB_TDMIX.C     ( Mixer Chip Engine )                                      //
// ------------------------------------------------------------------------- //
// Mario Hewardt  (mario@cs.montana.edu)                                     //
// Montana State University                                                  //
// Please read the AGREE.DOC before using.                                   //
// See SB_TDLIB.DOC or SB_TDNOT.DOC for additional information               //
// ------------------------------------------------------------------------- //




// ------------------------------------------------------------------------- //
// int SB_MIXER_Set_Adress ( struct SB_MIXER_Data, char func)                //
// ------------------------------------------------------------------------- //
int SB_MIXER_Set_Adress ( struct SB_MIXER_Data mix, char func )
{
    // mixer present?
    if ( mix.SB_MIXER_Version == 0 )
        return SB_TDRET_MIXERR;
    outp ( mix.SB_MIXER_Adress+4, func );      // set the reg. index
    return SB_TDRET_OK;
}


// ------------------------------------------------------------------------- //
// int SB_MIXER_Read ( struct SB_MIXER_Data )                                //
// ------------------------------------------------------------------------- //
int SB_MIXER_Read ( struct SB_MIXER_Data mix )
{
    // mixer present?
    if ( mix.SB_MIXER_Version == 0 )
        return SB_TDRET_MIXERR;
    return ( inp ( mix.SB_MIXER_Adress+5 ) );
}



// ------------------------------------------------------------------------- //
// int SB_MIXER_Write ( struct SB_MIXER_Data, char  )                        //
// ------------------------------------------------------------------------- //
int SB_MIXER_Write ( struct SB_MIXER_Data mix, char val )
{
    // mixer present?
    if ( mix.SB_MIXER_Version == 0 )
        return SB_TDRET_MIXERR;
    outp ( mix.SB_MIXER_Adress+5, val );
    return SB_TDRET_OK;
}



// ------------------------------------------------------------------------- //
// int SB_MIXER_Initialize ( struct SB_MIXER_Data *mix, int base, int dsp )  //
// ------------------------------------------------------------------------- //
int SB_MIXER_Initialize ( struct SB_MIXER_Data *mix, int base, int dsp )
{
    // Is a mixer present?
    if ( dsp < 2 )
    {
        mix->SB_MIXER_Version = 0;
        strcpy ( mix->SB_MIXER_Chip, "No Mixer present" );
        return SB_TDRET_MIXERR;  //nop.
    }
    mix->SB_MIXER_Adress=base;      // set the base adress (same as base IO )

    // Check which mixer is present
    switch ( dsp )
    {
        case 2: strcpy ( mix->SB_MIXER_Chip, "CT1335" );
                mix->SB_MIXER_Version=1;
                break;
        case 3: strcpy ( mix->SB_MIXER_Chip, "CT1345" );
                mix->SB_MIXER_Version=2;
                break;
        case 4: strcpy ( mix->SB_MIXER_Chip, "CT1745" );
                mix->SB_MIXER_Version=3;
                break;
    }

    // Reset Mixer and load default reg. values
    outp ( mix->SB_MIXER_Adress+4, 0 );      // set the reset index
    outp ( mix->SB_MIXER_Adress+5, 69);      // out any byte to reset MIXER

    return SB_TDRET_OK;
}





