// ------------------------------------------------------------------------- //
// SB_TDMIX.H     ( Mixer Chip Engine )                                      //
// ------------------------------------------------------------------------- //
// Mario Hewardt  (mario@cs.montana.edu)                                     //
// Montana State University                                                  //
// Please read the AGREE.DOC before using.                                   //
// See SB_TDLIB.DOC or SB_TDNOT.DOC for additional information               //
// ------------------------------------------------------------------------- //



// Make sure sb_tdmix.h doesnt get included more than once.
#ifndef __SBTDMIX
#define __SBTDMIX


// Input Sources
#define SB_MIXER_MICROPHONE_SRC   0
#define SB_MIXER_CD_SRC           1
#define SB_MIXER_LINE_SRC         3
#define SB_MIXER_FILTER_ON        0
#define SB_MIXER_FILTER_OFF       1
#define SB_MIXER_LOWPASSFILTER_32 0
#define SB_MIXER_LOWPASSFILTER_88 1
#define SB_MIXER_STEREO_ON        1
#define SB_MIXER_STEREO_OFF       0

// Mixer data structure
struct SB_MIXER_Data
{
    int SB_MIXER_Adress;
   char SB_MIXER_Chip[15];
    int SB_MIXER_Version;   // 0=None, 1=CT1335, 2=CT1345, 3=CT1745
};


// function prototypes
int SB_MIXER_Set_Adress ( struct SB_MIXER_Data, char );
int SB_MIXER_Read       ( struct SB_MIXER_Data       );
int SB_MIXER_Write      ( struct SB_MIXER_Data, char );

// function prototypes for CT1345 (SBPRO)
int SB_CT1345_Present          ( struct SB_MIXER_Data );
int SB_CT1345_Get_Source       ( struct SB_MIXER_Data );
int SB_CT1345_Get_StereoSwitch ( struct SB_MIXER_Data );
int SB_CT1345_Get_InputFilter  ( struct SB_MIXER_Data );
int SB_CT1345_Get_OutputFilter ( struct SB_MIXER_Data );
int SB_CT1345_Get_LowPassFilter( struct SB_MIXER_Data );
int SB_CT1345_Get_MasterVolL   ( struct SB_MIXER_Data );
int SB_CT1345_Get_MasterVolR   ( struct SB_MIXER_Data );
int SB_CT1345_Get_MIDIVolL     ( struct SB_MIXER_Data );
int SB_CT1345_Get_MIDIVolR     ( struct SB_MIXER_Data );
int SB_CT1345_Get_CDVolL       ( struct SB_MIXER_Data );
int SB_CT1345_Get_CDVolR       ( struct SB_MIXER_Data );
int SB_CT1345_Get_LineVolL     ( struct SB_MIXER_Data );
int SB_CT1345_Get_LineVolR     ( struct SB_MIXER_Data );
int SB_CT1345_Get_VoiceVolL    ( struct SB_MIXER_Data );
int SB_CT1345_Get_VoiceVolR    ( struct SB_MIXER_Data );
int SB_CT1345_Get_MicVol       ( struct SB_MIXER_Data );
int SB_CT1345_Set_Source       ( struct SB_MIXER_Data, char );
int SB_CT1345_Set_StereoSwitch ( struct SB_MIXER_Data, char );
int SB_CT1345_Set_InputFilter  ( struct SB_MIXER_Data, char );
int SB_CT1345_Set_OutputFilter ( struct SB_MIXER_Data, char );
int SB_CT1345_Set_LowPassFilter( struct SB_MIXER_Data, char );
int SB_CT1345_Set_MasterVolL   ( struct SB_MIXER_Data, char );
int SB_CT1345_Set_MasterVolR   ( struct SB_MIXER_Data, char );
int SB_CT1345_Set_MIDIVolL     ( struct SB_MIXER_Data, char );
int SB_CT1345_Set_MIDIVolR     ( struct SB_MIXER_Data, char );
int SB_CT1345_Set_CDVolL       ( struct SB_MIXER_Data, char );
int SB_CT1345_Set_CDVolR       ( struct SB_MIXER_Data, char );
int SB_CT1345_Set_LineVolL     ( struct SB_MIXER_Data, char );
int SB_CT1345_Set_LineVolR     ( struct SB_MIXER_Data, char );
int SB_CT1345_Set_VoiceVolL    ( struct SB_MIXER_Data, char );
int SB_CT1345_Set_VoiceVolR    ( struct SB_MIXER_Data, char );
int SB_CT1345_Set_MicVol       ( struct SB_MIXER_Data, char );

// Include files for different types of Mixers
#include "sb_tdmix.c"   // General code
#include "sb_td345.c"   // Code for the CT1345 Mixer

#endif  // __SBTDMIX



