// ------------------------------------------------------------------------- //
// SB_TDTRF.C	  ( DSP/DMA Transfer Modes )								 //
// ------------------------------------------------------------------------- //
// Mario Hewardt  (mario@cs.montana.edu)									 //
// Montana State University 												 //
// Please read the AGREE.DOC before using.									 //
// See SB_TDLIB.DOC or SB_TDNOT.DOC for additional information				 //
// ------------------------------------------------------------------------- //


// -------------- DUMMY INTs ----------------
static void interrupt SB_Dummy_Handler ( SB_TDIRQARGS )
{
	SB_tag=1;
	SB_DSP_AcknowInt  ( SB_base, SB_irq );
	SB_IRQ_End ( SB_irq );
}


// ====================== 8/16 BIT DSP TRANSFERS =========================== //

// ------------------------------------------------------------------------- //
// int SB_DSP_SC8_Transfer ( int, int, int, int )	   (SB) 				 //
// 8 BIT SINGLE CYCLE TRANSFER MODE 										 //
// ------------------------------------------------------------------------- //
void SB_DSP_SC8_Transfer ( int base, USWORD numb, int samp_rate, int transmode,
						  struct SB_MIXER_Data mix )
{
	USCHAR time_constant=256-(1000000L/samp_rate); numb--;

	SB_DSP_Write ( base, SB_DSP_TIMECONST );   // prepare for set time constant
	SB_DSP_Write ( base, time_constant	  );   // set time const.
	SB_DSP_Write ( base, transmode		  );   // set transfer mode

	SB_DSP_Write ( base, (numb&0x0FF) );  // LSB of length
	SB_DSP_Write ( base, (numb>>8)	  );  // MSB of length
}



// ------------------------------------------------------------------------- //
// int SB_DSP_AI8_Transfer ( int, int, int, int )	   (SB2.0)				 //
// 8 BIT AUTO INITIALIZE TRANSFER MODE										 //
// ------------------------------------------------------------------------- //
void SB_DSP_AI8_Transfer ( int base, USWORD numb, int samp_rate, int transmode,
						  struct SB_MIXER_Data mix, struct SB_DMA_Data *dma,
						  struct SB_Data *sb  )
{
	SB_FUNCPTR old;
	struct SB_DMA_Data tmp;

	USCHAR time_constant=256-(1000000L/samp_rate); numb--;
    if ( transmode != SB_DSP_PCM_AIHSINP && transmode != SB_DSP_PCM_AIHSOUT )
	{
		SB_DSP_Write ( base, SB_DSP_TIMECONST );   // prepare for set time constant
		SB_DSP_Write ( base, time_constant	  );   // set time const.
		SB_DSP_Write ( base, SB_DSP_DMASIZE   );   // Set DMA Block Size
		SB_DSP_Write ( base, (numb&0x0FF)	  );   // LSB of length
		SB_DSP_Write ( base, (numb>>8)		  );   // MSB of length
		SB_DSP_Write ( base, transmode		  );   // set transfer mode
	}
	// Stereo Mode
	else
	{
            /*SB_int = sb->SB_IRQ;
			SB_bio = sb->SB_BaseIO;
			SB_CT1345_Set_StereoSwitch ( mix, SB_MIXER_STEREO_ON ); // stereo on
			SB_IRQ_SetMask ();
			old = SB_IRQ_SetHandler ( SB_int,SB_Dummy_Handler );
			SB_IRQ_Enable ( SB_int );

			// Program transfer for 1 sylent byte DMA
			SB_DMA_Alloc ( &tmp, 1 );
            tmp.SB_DMA_Channel = dma->SB_DMA_Channel;
			tmp.SB_DMA_Mode = SB_DMA8_SSWRITE;
			SB_DMA_Transfer ( &tmp );
			SB_DSP_SC8_Transfer ( SB_bio, 0, 23000, SB_DSP_PCM_SSOUT, mix );
            while ( SB_tag != 1 )
                ;
            old = SB_IRQ_SetHandler ( SB_int, old );
            SB_IRQ_RestoreMask ();
            SB_DMA_Free ( &tmp );*/
	}
}




// ====================== 8/16 BIT DMA TRANSFERS ========================= //

// ------------------------------------------------------------------------- //
// int SB_DMA_Transfer ( struct SB_DMA_Data * ) 							 //
// ------------------------------------------------------------------------- //
void SB_DMA_Transfer ( struct SB_DMA_Data *dma	)
{
		SB_DMA_Cdisable( dma->SB_DMA_Channel );  // disable the channel we're gonna use...
		SB_DMA_Cclear  ( dma->SB_DMA_Channel );  // clear ptr.
		SB_DMA_Cmode   ( dma ); 				 // set transfer mode for channel
		SB_DMA_Coffset ( dma ); 				 // set offset
		SB_DMA_Cpage   ( dma ); 				 // set page
		SB_DMA_Clength ( dma ); 				 // set length
		SB_DMA_Cenable ( dma->SB_DMA_Channel );  // EEAHHH!! Enable the DMA channel
}




