// ------------------------------------------------------------------------- //
// SB_TDTRF.H	  ( DSP/DMA Transfer Modes Header File )					 //
// ------------------------------------------------------------------------- //
// Mario Hewardt  (mario@cs.montana.edu)									 //
// Montana State University 												 //
// Please read the AGREE.DOC before using.									 //
// See SB_TDLIB.DOC or SB_TDNOT.DOC for additional information				 //
// ------------------------------------------------------------------------- //


#ifndef __SBTDRET
#include "sb_tdret.h"
#endif

#ifndef __SBTDTRF
#define __SBTDTRF


int SB_int;
int SB_tag=0;
int SB_bio;

#include "sb_tddma.h"
#include "sb_tdmix.h"           // MIXER functions


// function prototypes
// -------------------
int            SB_DSP_SC8_Transfer ( int, int, int, int, struct SB_MIXER_Data    );       // (SB or SBPRO)
int            SB_DSP_AI8_Transfer ( int, USWORD, int, int, struct SB_MIXER_Data, struct SB_DMA_Data *, struct SB_Data *);       // (SB2.0 or SBPRO)
int 		   SB_DMA_Transfer	   ( struct SB_DMA_Data *  );


// 8 Bit DSP Transfer Modes
// ------------------------
// -- Single Cycle --
#define SB_DSP_PCM_SSINP		 0x24		  // 8 bit PCM Input
#define SB_DSP_PCM_SSOUT		 0x14		  // 8 bit PCM Output
#define SB_DSP_ADPCM84_SSOUT	 0x75		  // 8 to 4 bit ADPCM with ref. byte
#define SB_DSP_ADPCM83_SSOUT	 0x77		  // 8 to 3 bit ADPCM with ref. byte
#define SB_DSP_ADPCM82_SSOUT	 0x17		  // 8 to 2 bit ADPCM with ref. byte
#define SB_DSP_PCM_SSHINP		 0x99		  // 8 bit PCM Input High Speed
#define SB_DSP_PCM_SSHOUT		 0x91		  // 8 bit PCM Output High Speed
#define SB_DSP_PCM_SSHSINP		 0x99		  // 8 bit PCM Input High Speed Stereo
#define SB_DSP_PCM_SSHSOUT		 0x91		  // 8 bit PCM Output High Speed Stereo

// -- Auto Init --
#define SB_DSP_PCM_AIINP		 0x2C		  // 8 bit PCM Input
#define SB_DSP_PCM_AIOUT		 0x1C		  // 8 bit PCM Output
#define SB_DSP_ADPCM84_AIOUT	 0x7D		  // 8 to 4 bit ADPCM with ref. byte
#define SB_DSP_ADPCM83_AIOUT	 0x7F		  // 8 to 3 bit ADPCM with ref. byte
#define SB_DSP_ADPCM82_AIOUT	 0x1F		  // 8 to 2 bit ADPCM with ref. byte
#define SB_DSP_PCM_AIHINP		 0x98		  // 8 bit PCM Input High Speed
#define SB_DSP_PCM_AIHOUT		 0x90		  // 8 bit PCM Output High Speed
#define SB_DSP_PCM_AIHSINP		 0x98		  // 8 bit PCM Input High Speed Stereo
#define SB_DSP_PCM_AIHSOUT		 0x90		  // 8 bit PCM Output High Speed Stereo



// DMA Transfer Modes
// ------------------
#define SB_DMA8_SSWRITE 0x44		// 8 Bit Single Cycle DMA Transfer Write
#define SB_DMA8_SSREAD	0x48		// 8 Bit Single Cycle DMA Transfer Read
#define SB_DMA8_AIWRITE 0x54		// 8 Bit Auto Initialize DMA Transfer Write
#define SB_DMA8_AIREAD	0x58		// 8 Bit Auto Initialize DMA Transfer Read


#include "sb_tdtrf.c"


#endif // __SBTDTRF
