// ------------------------------------------------------------------------- //
// SB_TDWAV.C	  ( Wave File Loader )										 //
// ------------------------------------------------------------------------- //
// Mario Hewardt  (mario@cs.montana.edu)									 //
// Montana State University 												 //
// Please read agree.txt before using										 //
// Freeware - with some restrictions										 //
// ------------------------------------------------------------------------- //



// ------------------------------------------------------------------------- //
// void SB_IRQ_Handler ( SB_TDIRQARGS ) 									 //
// ------------------------------------------------------------------------- //
static void interrupt SB_Wave_Handler ( SB_TDIRQARGS )
{
	if ( SB_buffer==0 )
	{
		// at the end, go into single cycle plz.....hehehe
		//SB_DSP_Write ( SB_base, SB_DSP_PCM_SSOUT );
		//SB_DSP_Write ( SB_base, (SB_slength-SB_lcount) );
		//SB_DSP_Write ( SB_base, (SB_slength-SB_lcount)>>8);
		SB_DSP_Reset ( SB_base );
		SB_flag=1;
	}
	else if ( SB_buffer==1 )
		{SB_buffer=1;SB_flag=0;}
	else
		{SB_buffer=2;SB_flag=0;}


	SB_DSP_AcknowInt  ( SB_base, SB_irq );
	SB_IRQ_End ( SB_irq );
}






// ------------------------------------------------------------------------- //
// int SB_Wave_Status ( )													 //
// ------------------------------------------------------------------------- //
int SB_Wave_Status ( )
{
	if ( SB_flag==1) return SB_TDRET_WAVDONE;
	return SB_TDRET_WAVNOTDONE;
}



// ------------------------------------------------------------------------- //
// int SB_Wave_LoadInfo ( char *, struct SB_Wave_Data * )					 //
// ------------------------------------------------------------------------- //
int SB_Wave_LoadInfo ( char *fname, struct SB_Wave_Data *wave )
{
	UDWORD len;
	USWORD fla;
	char tmp[20];
	int fh;

	fh=open ( fname, O_RDONLY|O_BINARY );
	if ( fh==-1 ) return SB_TDRET_FILEERR;	  // file not found or something....

	// ok..now lets check the file for RIFF
	read ( fh, tmp, 4 );	   // read 4 bytes
	tmp[4]=0;

	if ( ( strcmp ( tmp, "RIFF" ) ) != 0 )
		return SB_TDRET_RIFERR; 		 // not a valid RIFF file

	// ok.. now lets see how long the actuall sample data is.....
	read ( fh, &len, 4 );

	// lets check the wave
	read ( fh, tmp, 4 );
	tmp[4]=0;
	if ( ( strcmp ( tmp, "WAVE" ) ) != 0 )
		return SB_TDRET_WAVERR; 	 // not a valid wave file


	read ( fh,tmp, 4 );
	tmp[3]=0;
	if ( ( strcmp ( tmp, "fmt" ) ) != 0 )
		return SB_TDRET_FORMERR;	  // no valid format specs.
	read (fh,tmp,4);	// skip these bytes

	read (fh,&fla,2);	 // get format
	wave->SB_Wave_Format=fla;

	read (fh,&fla,2);	 // get # of channels (1=mono	2=stereo)
	wave->SB_Wave_Nrchannels=fla;

	read (fh,&fla,2);	 // get playback frequency
	wave->SB_Wave_Frequency=fla;

	read (fh,tmp,10);	 // skip these bytes

	read (fh,tmp,4);	// read "data" field
	tmp[4]=0;
	if ( ( strcmp ( tmp, "data" ) ) != 0 )
		return SB_TDRET_DATAERR;	  // no valid data.
	read (fh,&len,4);
	wave->SB_Wave_Dlen=len;

	// now read in the sample data
	wave->SB_Wave_Ptr = (char *) malloc ( wave->SB_Wave_Dlen );
	if ( wave->SB_Wave_Ptr == NULL ) return SB_TDRET_MEMERR;
	lseek ( fh,0x2E,0 ); // make sure were at the right spot
	read ( fh, wave->SB_Wave_Ptr, wave->SB_Wave_Dlen );
	SB_slength=wave->SB_Wave_Dlen;
	SB_ptr=wave->SB_Wave_Ptr;
	close ( fh );

	return SB_TDRET_OK; 		  // done
}



// ------------------------------------------------------------------------- //
// int SB_Wave_Play (  struct SB_Wave_Data *, struct SB_Data * )			 //
// ------------------------------------------------------------------------- //
void SB_Wave_Play ( struct SB_Wave_Data *wave, struct SB_Data *sb,
				   struct SB_MIXER_Data mix )
{

	SB_base=sb->SB_BaseIO;
	SB_irq=sb->SB_IRQ;

	SB_IRQ_SetMask	  ( );
	SB_old = SB_IRQ_SetHandler ( sb->SB_IRQ, SB_Wave_Handler );
	SB_IRQ_Enable ( sb->SB_IRQ );

	dma.SB_DMA_Channel=sb->SB_DMA8_Channel;
	dma.SB_DMA_Mode = SB_DMA8_AIREAD;
	SB_DMA_Alloc ( &dma, SB_bufsize );
	SB_Wave_Prep ( dma, wave );
	SB_DSP_SpeakOnOff ( sb->SB_BaseIO, 1 );
	SB_DMA_Transfer ( &dma );
	SB_DSP_AI8_Transfer ( sb->SB_BaseIO, (SB_bufsize/2),
                           wave->SB_Wave_Frequency, SB_DSP_PCM_AIOUT, mix,
						   &dma, sb );

}




// ------------------------------------------------------------------------- //
// int SB_Wave_Stop ( ) 													 //
// ------------------------------------------------------------------------- //
void SB_Wave_Stop ( struct SB_Wave_Data *wave )
{
	SB_old = SB_IRQ_SetHandler ( SB_irq, SB_old );
	SB_IRQ_RestoreMask ( );
	SB_DSP_SpeakOnOff ( SB_base, 0 );
	SB_DMA_Free ( &dma );
	free ( wave->SB_Wave_Ptr );
}



// ------------------------------------------------------------------------- //
// int SB_Wave_Prep (  struct SB_DMA_Data , struct SB_Wave_Data  )			 //
// ------------------------------------------------------------------------- //
int SB_Wave_Prep ( struct SB_DMA_Data dma, struct SB_Wave_Data *wave )
{

	char *dmabuf; int index;
	dmabuf=(USCHAR *)dma.SB_DMA_Cont;
	for ( index=0; index<(SB_bufsize/2); index++ )
	{
		if ( SB_lcount+index > SB_slength )
			*(dmabuf+index)= 0;
		else
			*(dmabuf+index)=*(wave->SB_Wave_Ptr+index);
	}

	SB_lcount+=(SB_bufsize/2);
	SB_flag=0;
	SB_buffer=1;
	SB_dmabuf=dmabuf;
	return 1;
}





// ------------------------------------------------------------------------- //
// void SB_Wave_Update ( )													 //
// ------------------------------------------------------------------------- //
void SB_Wave_Update ( )
{
	int i;
	while ( SB_flag != 2 && SB_flag != 1 )
	{
		// are we at the end?
		if ( (SB_lcount+(SB_bufsize/2)) > SB_slength )
			{SB_flag=2; SB_buffer=0;}

		// fill buffer 2
		if (SB_buffer==1)
		{
			for ( i=0; i<(SB_bufsize/2); i++ )
				*(SB_dmabuf+(SB_bufsize/2)+i) = *(SB_ptr+SB_lcount+i);
			SB_lcount+=(SB_bufsize/2);
			SB_flag=2;
			SB_buffer=2;
		}

		// fill buffer 1
		else if ( SB_buffer==2 )
		{
			for ( i=0; i<(SB_bufsize/2); i++ )
				*(SB_dmabuf+i) = *(SB_ptr+SB_lcount+i);
			SB_lcount+=(SB_bufsize/2);
			SB_flag=2;
			SB_buffer=1;
		}
	}
}
